betty.project.factory module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.factory module

Functionality for creating new instances of types that depend on `betty.project.Project`.

class betty.project.factory.ProjectDependentFactory

  Bases: `ABC`

  Allow this type to be instantiated using a `betty.project.Project`.

  abstract async classmethod new_for_project(project: Project) → Self

    Create a new instance using the given project.